==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/ConnectionSettingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for a Connection Setting Item
 * @property clientId Client Id associated with the Connection Setting.
 * @property clientSecret Client Secret associated with the Connection Setting
 * @property id Id of the Connection Setting.
 * @property name Name of the Connection Setting.
 * @property parameters Service Provider Parameters associated with the Connection Setting
 * @property provisioningState Provisioning state of the resource
 * @property scopes Scopes associated with the Connection Setting
 * @property serviceProviderDisplayName Service Provider Display Name associated with the Connection Setting
 * @property serviceProviderId Service Provider Id associated with the Connection Setting
 */
public data class ConnectionSettingPropertiesArgs(
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val parameters: Output<List<ConnectionSettingParameterArgs>>? = null,
    public val provisioningState: Output<String>? = null,
    public val scopes: Output<String>? = null,
    public val serviceProviderDisplayName: Output<String>? = null,
    public val serviceProviderId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .scopes(scopes?.applyValue({ args0 -> args0 }))
            .serviceProviderDisplayName(serviceProviderDisplayName?.applyValue({ args0 -> args0 }))
            .serviceProviderId(serviceProviderId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionSettingPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionSettingPropertiesArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecret: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parameters: Output<List<ConnectionSettingParameterArgs>>? = null

    private var provisioningState: Output<String>? = null

    private var scopes: Output<String>? = null

    private var serviceProviderDisplayName: Output<String>? = null

    private var serviceProviderId: Output<String>? = null

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("gxveojvtgiatjjql")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("gseedibjfkjjyxnj")
    public suspend fun clientSecret(`value`: Output<String>) {
        this.clientSecret = value
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("krohhjkidpaktxic")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("qorjfikwalkpnujj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("rbfdmjgrtfwdjwrq")
    public suspend fun parameters(`value`: Output<List<ConnectionSettingParameterArgs>>) {
        this.parameters = value
    }

    @JvmName("crtwheypecbauwhp")
    public suspend fun parameters(vararg values: Output<ConnectionSettingParameterArgs>) {
        this.parameters = Output.all(values.asList())
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("xhxpdaadmcmcprmv")
    public suspend fun parameters(values: List<Output<ConnectionSettingParameterArgs>>) {
        this.parameters = Output.all(values)
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("hixdrtjeccgnjipp")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("nbtbeieckqllghqx")
    public suspend fun scopes(`value`: Output<String>) {
        this.scopes = value
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("lxgiakxdiogwvudt")
    public suspend fun serviceProviderDisplayName(`value`: Output<String>) {
        this.serviceProviderDisplayName = value
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("ukcxjenepsfwsjtq")
    public suspend fun serviceProviderId(`value`: Output<String>) {
        this.serviceProviderId = value
    }

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("qqmqcwnggoxtrrmc")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("igcxverwrbfwmdei")
    public suspend fun clientSecret(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("lxbpsxbkhjtudiio")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("ttpenjlpeevdjphh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("loyeveiuljkeejyk")
    public suspend fun parameters(`value`: List<ConnectionSettingParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("gujuggsawjiljpau")
    public suspend
    fun parameters(argument: List<suspend ConnectionSettingParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("gkqxybgededuqrmi")
    public suspend fun parameters(
        vararg
        argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("mjmtldnikfrbsyvq")
    public suspend
    fun parameters(argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionSettingParameterArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("oqqatwikkytwudjn")
    public suspend fun parameters(vararg values: ConnectionSettingParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("jgjlsendrjghdafs")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("amquxgnchdkmdujk")
    public suspend fun scopes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("auujerkyykjkltnk")
    public suspend fun serviceProviderDisplayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderDisplayName = mapped
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("hejopnehgcupwbvc")
    public suspend fun serviceProviderId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderId = mapped
    }

    internal fun build(): ConnectionSettingPropertiesArgs = ConnectionSettingPropertiesArgs(
        clientId = clientId,
        clientSecret = clientSecret,
        id = id,
        name = name,
        parameters = parameters,
        provisioningState = provisioningState,
        scopes = scopes,
        serviceProviderDisplayName = serviceProviderDisplayName,
        serviceProviderId = serviceProviderId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/ConnectionSettingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for a Connection Setting Item
 * @property clientId Client Id associated with the Connection Setting.
 * @property clientSecret Client Secret associated with the Connection Setting
 * @property id Id of the Connection Setting.
 * @property name Name of the Connection Setting.
 * @property parameters Service Provider Parameters associated with the Connection Setting
 * @property provisioningState Provisioning state of the resource
 * @property scopes Scopes associated with the Connection Setting
 * @property serviceProviderDisplayName Service Provider Display Name associated with the Connection Setting
 * @property serviceProviderId Service Provider Id associated with the Connection Setting
 */
public data class ConnectionSettingPropertiesArgs(
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val parameters: Output<List<ConnectionSettingParameterArgs>>? = null,
    public val provisioningState: Output<String>? = null,
    public val scopes: Output<String>? = null,
    public val serviceProviderDisplayName: Output<String>? = null,
    public val serviceProviderId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.ConnectionSettingPropertiesArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .scopes(scopes?.applyValue({ args0 -> args0 }))
            .serviceProviderDisplayName(serviceProviderDisplayName?.applyValue({ args0 -> args0 }))
            .serviceProviderId(serviceProviderId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionSettingPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectionSettingPropertiesArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecret: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parameters: Output<List<ConnectionSettingParameterArgs>>? = null

    private var provisioningState: Output<String>? = null

    private var scopes: Output<String>? = null

    private var serviceProviderDisplayName: Output<String>? = null

    private var serviceProviderId: Output<String>? = null

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("rojphhsykhedguqb")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("wlefchprjbfbajkm")
    public suspend fun clientSecret(`value`: Output<String>) {
        this.clientSecret = value
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("gyqmlugcbxryeocr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("wqdekbnglvlqxeor")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("tsakfitkxctjabqj")
    public suspend fun parameters(`value`: Output<List<ConnectionSettingParameterArgs>>) {
        this.parameters = value
    }

    @JvmName("tfqltalyyirtvbmc")
    public suspend fun parameters(vararg values: Output<ConnectionSettingParameterArgs>) {
        this.parameters = Output.all(values.asList())
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("yxfqktcuoxyghlrd")
    public suspend fun parameters(values: List<Output<ConnectionSettingParameterArgs>>) {
        this.parameters = Output.all(values)
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("buumtpgqtsqgnidr")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("nkuwqsopenglpgyc")
    public suspend fun scopes(`value`: Output<String>) {
        this.scopes = value
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("lbwhexocqppyvaje")
    public suspend fun serviceProviderDisplayName(`value`: Output<String>) {
        this.serviceProviderDisplayName = value
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("ucaphjmmkxntvgxh")
    public suspend fun serviceProviderId(`value`: Output<String>) {
        this.serviceProviderId = value
    }

    /**
     * @param value Client Id associated with the Connection Setting.
     */
    @JvmName("htmqjkthtgsbgcls")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Client Secret associated with the Connection Setting
     */
    @JvmName("jhlcrlkpajxnqvvs")
    public suspend fun clientSecret(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param value Id of the Connection Setting.
     */
    @JvmName("flgntosupqqlylwe")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the Connection Setting.
     */
    @JvmName("ewtjqqbbnmxlyqyt")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("rycyakricdvchsga")
    public suspend fun parameters(`value`: List<ConnectionSettingParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("qsyowbxvhhryphmu")
    public suspend
    fun parameters(argument: List<suspend ConnectionSettingParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("hqqqqaxbfqqunted")
    public suspend fun parameters(
        vararg
        argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionSettingParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param argument Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("fgydinognjynsuam")
    public suspend
    fun parameters(argument: suspend ConnectionSettingParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionSettingParameterArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    /**
     * @param values Service Provider Parameters associated with the Connection Setting
     */
    @JvmName("wyjjfcujcbybunms")
    public suspend fun parameters(vararg values: ConnectionSettingParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Provisioning state of the resource
     */
    @JvmName("yilacganpbbrhtnh")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Scopes associated with the Connection Setting
     */
    @JvmName("gdanhqrsyesdxhih")
    public suspend fun scopes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value Service Provider Display Name associated with the Connection Setting
     */
    @JvmName("ulsbojevtaoreqjn")
    public suspend fun serviceProviderDisplayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderDisplayName = mapped
    }

    /**
     * @param value Service Provider Id associated with the Connection Setting
     */
    @JvmName("irdwnnelxesahluh")
    public suspend fun serviceProviderId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderId = mapped
    }

    internal fun build(): ConnectionSettingPropertiesArgs = ConnectionSettingPropertiesArgs(
        clientId = clientId,
        clientSecret = clientSecret,
        id = id,
        name = name,
        parameters = parameters,
        provisioningState = provisioningState,
        scopes = scopes,
        serviceProviderDisplayName = serviceProviderDisplayName,
        serviceProviderId = serviceProviderId,
    )
}
